@@ -13,7 +13,7 @@ class BaseRepository(implements(InterfaceBaseRepository)):
     def execute_query(
             self,
             query: Query | T,
-    ) -> list[T]:
+    ) -> list[T] | T:
         """
         Выполнение запроса
         """
