@@ -7,8 +7,8 @@ from fireorm_repository.types.types import T
 class InterfaceBaseRepository(Interface):
     def execute_query(
             self,
-            query: Query,
-    ) -> list[T]:
+            query: Query | T,
+    ) -> list[T] | T:
         pass
 
     def get_by_id(
